[llvm-commits] CVS: llvm/include/llvm/CodeGen/AsmPrinter.h

Chris Lattner lattner at cs.uiuc.edu
Tue Aug 17 19:22:46 PDT 2004



Changes in directory llvm/include/llvm/CodeGen:

AsmPrinter.h updated: 1.8 -> 1.9
---
Log message:

Alkis pointed out that this is not a character (we actually support strings)
and as such, we should use self revealing names.  Hey, makes sense to me!


---
Diffs of the changes:  (+3 -3)

Index: llvm/include/llvm/CodeGen/AsmPrinter.h
diff -u llvm/include/llvm/CodeGen/AsmPrinter.h:1.8 llvm/include/llvm/CodeGen/AsmPrinter.h:1.9
--- llvm/include/llvm/CodeGen/AsmPrinter.h:1.8	Tue Aug 17 16:38:51 2004
+++ llvm/include/llvm/CodeGen/AsmPrinter.h	Tue Aug 17 21:22:34 2004
@@ -45,9 +45,9 @@
     // Properties to be set by the derived class ctor, used to configure the
     // asmwriter.
 
     /// CommentChar - This indicates the comment character used by the
     /// assembler.
-    const char *CommentChar;     // Defaults to "#"
+    const char *CommentString;     // Defaults to "#"
 
     /// GlobalPrefix - If this is set to a non-empty string, it is prepended
     /// onto all global symbols.  This is often used for "_" or ".".
@@ -84,7 +84,7 @@
 
     AsmPrinter(std::ostream &o, TargetMachine &tm)
       : O(o), TM(tm),
-        CommentChar("#"),
+        CommentString("#"),
         GlobalPrefix(""),
         ZeroDirective("\t.zero\t"),
         AsciiDirective("\t.ascii\t"),
@@ -45,9 +45,9 @@
     // asmwriter.
 
-    /// CommentChar - This indicates the comment character used by the
+    /// CommentString - This indicates the comment character used by the
     /// assembler.






More information about the llvm-commits mailing list